@@ -1,22 +1,21 @@
 import glob
+import html
+import json
 import os
 import re
-import html
 import textwrap
-import json
 from pathlib import Path
 from typing import List, Union, Tuple
 
 import pycountry
 from pyd2v import D2V
-from pymediainfo import MediaInfo
+from pymediainfo import MediaInfo, Track
 
 from pynfogen.formatter import CustomFormats
 from pynfogen.helpers import scrape
 
 
 class NFO:
-
     AUDIO_CHANNEL_LAYOUT_WEIGHT = {
         "LFE": 0.1
     }
@@ -39,9 +38,9 @@ class NFO:
         self.banner_image = None
         self.source = None
         self.note = None
-        self.videos = None
-        self.audio = None
-        self.subtitles = None
+        self.videos: List[Track] = []
+        self.audio: List[Track] = []
+        self.subtitles: List[Track] = []
         self.chapters = None
         self.chapters_numbered = None
 
@@ -91,10 +90,12 @@ class NFO:
         self.videos = self.media_info.video_tracks
         self.audio = self.media_info.audio_tracks
         self.subtitles = self.media_info.text_tracks
-        self.chapters = self.media_info.menu_tracks
-        self.chapters = None if not self.chapters else [v for k, v in self.chapters[0].to_data().items() if ("1" + k.replace("_", "")).isdigit()]
+        self.chapters = next(iter(self.media_info.menu_tracks), None)
+        if self.chapters:
+            self.chapters = [v for k, v in self.chapters.to_data().items() if f"1{k.replace('_', '')}".isdigit()]
         self.chapters_numbered = 0 if not self.chapters else sum(
-            1 for i, x in enumerate(self.chapters) if x.split(":", 1)[-1] in [f"Chapter {i+1}", f"Chapter {str(i+1).zfill(2)}"]
+            1 for i, x in enumerate(self.chapters)
+            if x.split(":", 1)[-1] in [f"Chapter {i + 1}", f"Chapter {str(i + 1).zfill(2)}"]
         ) == len(self.chapters)
 
         self.fanart_api_key = config.get("fanart_api_key")
@@ -116,7 +117,7 @@ class NFO:
         """Get IMDB, TMDB, TVDB IDs from Media Tags or config."""
         general = self.media_info.general_tracks[0].to_data()
         dbs = {"imdb": None, "tmdb": None, "tvdb": None}
-        for db in dbs.keys():
+        for db in dbs:
             if db in general and general[db]:
                 dbs[db] = general[db]
             elif db in config and config[db]:
@@ -207,8 +208,8 @@ class NFO:
                     if os.path.exists(fp):
                         os.unlink(fp)
             l1 = f"- {pycountry.languages.get(alpha_2=t.language).name}, {codec} " + \
-                f"({t.format_profile}) {t.width}x{t.height} ({t.other_display_aspect_ratio[0]}) " + \
-                f"@ {t.other_bit_rate[0]}{f' ({t.bit_rate_mode})' if t.bit_rate_mode else ''}"
+                 f"({t.format_profile}) {t.width}x{t.height} ({t.other_display_aspect_ratio[0]}) " + \
+                 f"@ {t.other_bit_rate[0]}{f' ({t.bit_rate_mode})' if t.bit_rate_mode else ''}"
             l2 = f"  {(f'{t.framerate_num}/{t.framerate_den}' if t.framerate_num else t.frame_rate)} FPS " + \
                  f"({'VFR' if vst else t.frame_rate_mode}), {t.color_space}{t.chroma_subsampling.replace(':', '')}" + \
                  f"P{t.bit_depth}, {interlaced_percent if interlaced_percent else t.scan_type}"
@@ -258,14 +259,51 @@ class NFO:
         return images
 
     @staticmethod
-    def get_subtitle_print(subs):
-        if not subs:
-            return ["--"]
+    def get_subtitle_print(subs: List[Track]) -> List[str]:
+        """
+        Return a list of a brief subtitle overview per-subtitle.
+
+        e.g.
+        - English, Forced, SubRip (SRT)
+        - English, SubRip (SRT)
+        - English, SDH, SubRip (SRT)
+        - Spanish, Latin American (SDH), SubRip (SRT)
+
+        The bit of text between the Language and the Subtitle format is the Track Title.
+        It can be of any format, but it is recommended to be used as shown above.
+
+        It will be returned as a list of strings with the `- ` already pre-pended to each entry.
+        """
         data = []
-        for t in subs:
-            title = t.title or pycountry.languages.get(alpha_2=t.language).name
-            l1 = f"- {title}, {t.format.replace('UTF-8', 'SubRip (SRT)')}"
-            data += [("  " + x if i > 0 else x) for i, x in enumerate(textwrap.wrap(l1, 64))]
+        if not subs:
+            data.append("--")
+        for sub in subs:
+            line = []
+
+            # following sub.title tree checks and supports three different language and title scenarios
+            # The second scenario is the recommended option to choose if you are open to choosing any
+            # The third scenario should be used if you have nothing unique to state about the track
+            # | Language     | Track Title                   | Output                                        |
+            # | ------------ | ----------------------------- | --------------------------------------------- |
+            # | es / Spanish | Spanish (Latin American, SDH) | - Spanish (Latin American, SDH), SubRip (SRT) |
+            # | es / Spanish | Latin American (SDH)          | - Spanish, Latin American (SDH), SubRip (SRT) |
+            # | es / Spanish | None                          | - Spanish, SubRip (SRT)                       |
+            language = pycountry.languages.get(alpha_2=sub.language).name
+            if sub.title:
+                if language.lower() in sub.title.lower():
+                    line.append(sub.title)
+                else:
+                    line.append(f"{language}, {sub.title}")
+            else:
+                line.append(language)
+
+            line.append(sub.format.replace("UTF-8", "SubRip (SRT)"))
+
+            line = "- " + ", ".join(line)
+            data += [
+                ("  " + x if i > 0 else x)
+                for i, x in enumerate(textwrap.wrap(line, 64))
+            ]
         return data
 
     @staticmethod
@@ -279,4 +317,4 @@ class NFO:
             return "No"
         if self.chapters_numbered:
             return f"Yes (Numbered 01-{str(len(chapters)).zfill(2)})"
-        return f"Yes (Named)"
+        return "Yes (Named)"
